@@ -1,5 +1,5 @@
 package XML::TMX::CWB;
-$XML::TMX::CWB::VERSION = '0.08';
+$XML::TMX::CWB::VERSION = '0.09';
 use warnings;
 use strict;
 use Lingua::PT::PLNbase;
@@ -85,9 +85,11 @@ Imports a TMX file (just two languages) to a parallel corpus on CWB.
 =cut
 
 sub _get_header_prop_list {
-    my ($reader, $prop) = @_;
+    my ($reader, $prop, $default) = @_;
 
-    return undef unless exists $reader->{header}{-prop}{$prop};
+    $default ||= [];
+
+    return $default unless exists $reader->{header}{-prop}{$prop};
 
     my $value = (ref($reader->{header}{-prop}{$prop}) eq "ARRAY")
               ? join(",",@{$reader->{header}{-prop}{$prop}})
@@ -135,8 +137,8 @@ sub toCWB {
                 join(", ", keys %tagged_languages);
         }
 
-        $s_attributes ||= _get_header_prop_list('pos-s-attributes');
-        $pos_fields   ||= _get_header_prop_list('pos-fields');
+        $s_attributes = _get_header_prop_list($reader, 'pos-s-attributes', $s_attributes);
+        $pos_fields   = _get_header_prop_list($reader, 'pos-fields', $pos_fields);
 
         $tag_data = {
             languages => \%tagged_languages,
